@@ -1,14 +1,14 @@
 import copy
 import json
 from typing import Union
-
+import abc
 import gym
 from gym.spaces import Box, Discrete
 import numpy as np
 import torch
 
 
-class Agent:
+class Agent(abc.ABC):
     """
     A global agent class that describe the interactions between our agent, and it's environment.
     """
@@ -56,8 +56,9 @@ class Agent:
         self.episode_time_step_id = 0
         self.under_test = test_episode
 
+    @abc.abstractmethod
     def action(self, state, explore=True):
-        return self.action_space.sample()
+        pass
 
     def process_interaction(self, action, reward, new_state, done, learn=True):
         self.episode_time_step_id += 1
@@ -93,6 +94,5 @@ class Agent:
     def save(self, load_dir):
         pass
 
-
     def load(self, load_dir):
         pass
\ No newline at end of file
